"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ApplicationBridge = exports.RESPONSE_WEB_VIEW_ACTION_REMOVE_LOCAL_STORAGE_PROPERTY_ERROR = exports.RESPONSE_WEB_VIEW_ACTION_REMOVE_LOCAL_STORAGE_PROPERTY_SUCCESS = exports.WEB_VIEW_ACTION_REMOVE_LOCAL_STORAGE_PROPERTY = exports.RESPONSE_REMOVE_PROPERTY_ERROR = exports.RESPONSE_REMOVE_PROPERTY_SUCCESS = exports.ACTION_REMOVE_PROPERTY = exports.RESPONSE_LOAD_PROPERTY_ERROR = exports.RESPONSE_LOAD_PROPERTY_SUCCESS = exports.ACTION_LOAD_PROPERTY = exports.RESPONSE_STORE_PROPERTY_ERROR = exports.RESPONSE_STORE_PROPERTY_SUCCESS = exports.ACTION_STORE_PROPERTY = exports.RESPONSE_PRINT_FORM_ERROR = exports.RESPONSE_PRINT_FORM_SUCCESS = exports.ACTION_PRINT_FORM = exports.RESPONSE_SEND_APPLICATION_STATE_ERROR = exports.RESPONSE_SEND_APPLICATION_STATE_SUCCESS = exports.ACTION_SEND_APPLICATION_STATE = exports.RESPONSE_PRINT_ERROR = exports.RESPONSE_PRINT_SUCCESS = exports.ACTION_PRINT = exports.RESPONSE_SCANBARCODE_ERROR = exports.RESPONSE_SCANBARCODE_SUCCESS = exports.ACTION_SCANBARCODE = void 0;
const tslib_1 = require("tslib");
const nsBridgewindowPropertyName = "nsWebViewBridge";
exports.ACTION_SCANBARCODE = "scanBarcode";
exports.RESPONSE_SCANBARCODE_SUCCESS = "scanBarcodeSuccess";
exports.RESPONSE_SCANBARCODE_ERROR = "scanBarcodeError";
exports.ACTION_PRINT = "print";
exports.RESPONSE_PRINT_SUCCESS = "printSuccess";
exports.RESPONSE_PRINT_ERROR = "printError";
exports.ACTION_SEND_APPLICATION_STATE = "sendApplicationState";
exports.RESPONSE_SEND_APPLICATION_STATE_SUCCESS = "sendApplicationStateSuccess";
exports.RESPONSE_SEND_APPLICATION_STATE_ERROR = "sendApplicationStateError";
exports.ACTION_PRINT_FORM = "printForm";
exports.RESPONSE_PRINT_FORM_SUCCESS = "printFormSuccess";
exports.RESPONSE_PRINT_FORM_ERROR = "printFormError";
exports.ACTION_STORE_PROPERTY = "storeProperty";
exports.RESPONSE_STORE_PROPERTY_SUCCESS = "storePropertySuccess";
exports.RESPONSE_STORE_PROPERTY_ERROR = "storePropertyError";
exports.ACTION_LOAD_PROPERTY = "loadProperty";
exports.RESPONSE_LOAD_PROPERTY_SUCCESS = "loadPropertySuccess";
exports.RESPONSE_LOAD_PROPERTY_ERROR = "loadPropertyError";
exports.ACTION_REMOVE_PROPERTY = "removeProperty";
exports.RESPONSE_REMOVE_PROPERTY_SUCCESS = "removePropertySuccess";
exports.RESPONSE_REMOVE_PROPERTY_ERROR = "removePropertyError";
// vvvv actions that will be sent the other way around (to the webview)
exports.WEB_VIEW_ACTION_REMOVE_LOCAL_STORAGE_PROPERTY = "webViewRemoveLocalStorageProperty";
exports.RESPONSE_WEB_VIEW_ACTION_REMOVE_LOCAL_STORAGE_PROPERTY_SUCCESS = "webViewRemoveLocalStoragePropertySuccess";
exports.RESPONSE_WEB_VIEW_ACTION_REMOVE_LOCAL_STORAGE_PROPERTY_ERROR = "webViewRemoveLocalStoragePropertyError";
/**
 * Bridge between the native "Applications" App and a Website
 */
class ApplicationBridge {
    constructor() {
        this.nsBridgeReady = false;
        if (this.isAvailable())
            this.nsBridgeReady = true;
        else {
            window.addEventListener("ns-bridge-ready", function (e) {
                this.nsBridgeReady = true;
            });
            void this.getNsBridge$().then((nsWebViewBridge) => {
                // register webview events that came from outside
                nsWebViewBridge.on(exports.WEB_VIEW_ACTION_REMOVE_LOCAL_STORAGE_PROPERTY, (key) => {
                    localStorage.removeItem(key);
                });
            });
        }
    }
    getNsBridge() {
        if (!this.isAvailable())
            throw new Error("NSBridge not ready, please call isAvailable first to prevent this error!");
        return window[nsBridgewindowPropertyName];
    }
    /**
     * Resolves as soon as bridge is available
     */
    getNsBridge$() {
        return this.isAvailable$().then(() => {
            return this.getNsBridge();
        });
    }
    isAvailable() {
        return window[nsBridgewindowPropertyName] !== undefined;
    }
    /**
     * Resolves as soon as bridge is available
     */
    isAvailable$() {
        if (this.nsBridgeReady === true)
            return Promise.resolve();
        return new Promise((resolve) => {
            window.addEventListener("ns-bridge-ready", function (e) {
                resolve();
            });
        });
    }
    sendApplicationState(applicationState) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return this.sendData(applicationState, exports.ACTION_SEND_APPLICATION_STATE, exports.RESPONSE_SEND_APPLICATION_STATE_SUCCESS, exports.RESPONSE_SEND_APPLICATION_STATE_ERROR);
        });
    }
    scanBarcode() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return this.sendData(undefined, exports.ACTION_SCANBARCODE, exports.RESPONSE_SCANBARCODE_SUCCESS, exports.RESPONSE_SCANBARCODE_ERROR);
        });
    }
    printVisitor(visitor, event) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const data = visitor.fields;
            data.USER_ID = visitor.id;
            return this.sendData({ formId: event === null || event === void 0 ? void 0 : event.formId, content: data }, exports.ACTION_PRINT_FORM, exports.RESPONSE_PRINT_FORM_SUCCESS, exports.RESPONSE_PRINT_FORM_ERROR);
        });
    }
    getProperty(key) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return this.sendData(key, exports.ACTION_LOAD_PROPERTY, exports.RESPONSE_LOAD_PROPERTY_SUCCESS, exports.RESPONSE_LOAD_PROPERTY_ERROR);
        });
    }
    saveProperty(key, value) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return this.sendData({ key, value }, exports.ACTION_STORE_PROPERTY, exports.RESPONSE_STORE_PROPERTY_SUCCESS, exports.RESPONSE_STORE_PROPERTY_ERROR);
        });
    }
    removeProperty(key) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return this.sendData(key, exports.ACTION_REMOVE_PROPERTY, exports.RESPONSE_REMOVE_PROPERTY_SUCCESS, exports.RESPONSE_REMOVE_PROPERTY_ERROR);
        });
    }
    sendData(data, eventName, successEventName, errorEventName) {
        if (!this.isAvailable())
            throw new Error("Nativescript Bridge not available!");
        return new Promise((resolve, reject) => {
            window[nsBridgewindowPropertyName].on(successEventName, (data) => {
                resolve(data);
                this.unregisterEvents(successEventName, errorEventName);
            });
            window[nsBridgewindowPropertyName].on(errorEventName, (error) => {
                reject(error);
                this.unregisterEvents(successEventName, errorEventName);
            });
            window[nsBridgewindowPropertyName].emit(eventName, data);
        });
    }
    unregisterEvents(...events) {
        events.forEach((e) => window[nsBridgewindowPropertyName].off(e));
    }
}
exports.ApplicationBridge = ApplicationBridge;
//# sourceMappingURL=application-bridge.js.map